==> haskell-floskell-0.10.8-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-ALZkWqMAOhdBo7AMUBRks6
key:                  floskell-0.10.8-ALZkWqMAOhdBo7AMUBRks6
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  f9cec22eb2cf7cfc5906f38cb18c87ed
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-ALZkWqMAOhdBo7AMUBRks6
depends:
    aeson-2.1.2.1-GhEX0nU3rpe2rpNz8TrqEz
    attoparsec-0.14.4-CZt0qAnGZHQHCYZEsndAye base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM directory-1.3.7.1
    filepath-1.4.2.2 haskell-src-exts-1.23.1-I3rt1leEiD31mFkfvbq7tR
    monad-dijkstra-0.1.1.5-FCoPn2Nq1Rx3tC9z30TAik mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-psp1ib8v1R5J9F619BTWH
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-floskell-0.10.8-152-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-KL534j5CmDOLj3vbOtQOyp
key:                  floskell-0.10.8-KL534j5CmDOLj3vbOtQOyp
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  d5c9b34470e8e029ac8c8fc3b42d8e82
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-KL534j5CmDOLj3vbOtQOyp
depends:
    aeson-2.1.2.1-56YME0rnoff9HEf3dDitk2
    attoparsec-0.14.4-HrmGc7uWcHZBxPSUhHwhWb base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM directory-1.3.7.1
    filepath-1.4.2.2 haskell-src-exts-1.23.1-GA5r5efYLUO4NdbY9KDDCU
    monad-dijkstra-0.1.1.5-14zaNHUZhiV254UUV7cAcP mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-90liAnN3BtD8VAzg2AGnlq
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
